/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.template.debug;


/**
 * Debugger to track start/result/end report merge Java model with document with
 * {@link ITemplateEngineDebugger}.
 * 
 */
public interface ITemplateEngineDebugger {

	/**
	 * Return true if result of merge with template engine must be displayed and
	 * false otherwise. If result of merge with template engine is true, time of
	 * process is affected to write result.
	 * 
	 * @return
	 */
	boolean isDisplayResult();

	/**
	 * Start process template engine (templateEngineId is velocity, freemarker)
	 * for the XML file entryName from the Zip.
	 * 
	 * @param templateEngineId
	 *            the ID of the template engine.
	 * @param entryName
	 *            XML file entryName from the Zip
	 * @param useTemplateCache
	 *            true if template cache must be used and false otherwise.
	 */
	void startProcessTemplateEngine(String templateEngineId, String entryName,
			boolean useTemplateCache);

	/**
	 * Display result of the merge Java model with XML file entryName.
	 * 
	 * @param templateEngineId
	 *            the ID of the template engine.
	 * @param entryName
	 *            XML file entryName from the Zip.
	 * @param result
	 *            of the merge Java model with XML file entryName.
	 */
	void resultOfProcessTemplateEngine(String templateEngineId,
			String entryName, String result);

	/**
	 * End process template engine (templateEngineId is velocity, freemarker)
	 * for the XML file entryName from the Zip.
	 * 
	 * @param templateEngineId
	 *            the ID of the template engine.
	 * @param entryName
	 *            XML file entryName from the Zip.
	 * @param time
	 *            time for merge Java model with document with template engine.
	 * @param e
	 *            exception if there is error while merge Java model with
	 *            document with template engine.
	 */
	void endProcessTemplateEngine(String templateEngineId, String entryName,
			long time, Throwable e);

}
