/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.template.discovery;

import fr.opensagres.xdocreport.core.discovery.IBaseDiscovery;
import fr.opensagres.xdocreport.template.ITemplateEngine;

/**
 * Discovery used to retrieve default template engine to use for report
 * generation when an {@link IXDocReport} is created with
 * {@link XDocReportLoader#loadReport(java.io.InputStream)} without specifying
 * the template engine.
 * 
 * <p>
 * An implementation template engine discovery is declared in the
 * xdocreport-discovery.properties with 'class' property. Example :
 * 
 * <pre>
 * -------------------------
 *  class=fr.opensagres.xdocreport.template.freemarker.discovery.FreemarkerTemplateEngineDiscovery
 *  -------------
 * </pre>
 * 
 * </p>
 * 
 */
public interface ITemplateEngineDiscovery extends IBaseDiscovery {

	/**
	 * Returns the default template engine to use for report generation when an
	 * {@link IXDocReport} is created with
	 * {@link XDocReportRegistry#loadReport(java.io.InputStream)} without
	 * specifying the template engine.
	 * 
	 * @return
	 */
	ITemplateEngine createTemplateEngine();
}
